@@ -94,11 +94,11 @@ on_about_activate (GtkMenuItem *menuitem, gpointer user_data)
 	static const gchar copyright[] = "Copyright \xc2\xa9 2005-2010 Fabio Marzocca";
 
 	gtk_show_about_dialog (NULL,
-		"name", _("Baobab"),
+		"name", _("Disk Usage Analyzer"),
 		"comments", _("A graphical tool to analyze disk usage."),
 		"version", VERSION,
 		"copyright", copyright,
-		"logo-icon-name", "baobab",
+		"logo-icon-name", "mate-disk-usage-analyzer",
 		"license", license_trans,
 		"authors", authors,
 		"translator-credits", _("translator-credits"),
